@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2020 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -50,8 +50,8 @@
 
 #define APPENDS 1000000
 
-DEFINE_VECTOR_TYPE(int64_vector, int64_t);
-DEFINE_VECTOR_TYPE(uint32_vector, uint32_t);
+DEFINE_VECTOR_TYPE (int64_vector, int64_t);
+DEFINE_VECTOR_TYPE (uint32_vector, uint32_t);
 
 static int
 compare (const int64_t *a, const int64_t *b)
@@ -64,11 +64,10 @@ test_int64_vector (void)
 {
   int64_vector v = empty_vector;
   size_t i;
-  int r;
   int64_t tmp, *p;
 
   for (i = 0; i < 10; ++i) {
-    r = int64_vector_insert (&v, i, 0);
+    int r = int64_vector_insert (&v, i, 0);
     assert (r == 0);
   }
 
