@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2020 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -44,24 +44,38 @@
 #include <assert.h>
 #include <string.h>
 
+#include "compiler-macros.h"
+#include "static-assert.h"
+
+#ifdef __clang__
+#pragma clang diagnostic ignored "-Wunused-function"
+#pragma clang diagnostic ignored "-Wduplicate-decl-specifier"
+#endif
+
 /* Use of this macro defines a new type called ‘name’ containing an
  * extensible vector of ‘type’ elements.  For example:
  *
- *   DEFINE_VECTOR_TYPE(string_vector, char *)
+ *   DEFINE_VECTOR_TYPE (string_vector, char *);
  *
  * defines a new type called ‘string_vector’ as a vector of ‘char *’.
  * You can create variables of this type:
  *
  *   string_vector names = empty_vector;
  *
- * where ‘names.ptr[]’ will be an array of strings and ‘names.size’
+ * or
+ *
+ *   string_vector names;
+ *   names = (string_vector)empty_vector;
+ *
+ * where ‘names.ptr[]’ will be an array of strings and ‘names.len’
  * will be the number of strings.  There are no get/set accessors.  To
  * iterate over the strings you can use the ‘.ptr’ field directly:
  *
- *   for (size_t i = 0; i < names.size; ++i)
+ *   for (size_t i = 0; i < names.len; ++i)
  *     printf ("%s\n", names.ptr[i]);
  *
- * Initializing with ‘empty_vector’ sets ‘.ptr = NULL’ and ‘.size = 0’.
+ * Initializing with ‘empty_vector’, or assigning the compound literal
+ * ‘(string_vector)empty_vector’, sets ‘.ptr = NULL’ and ‘.len = 0’.
  *
  * DEFINE_VECTOR_TYPE also defines utility functions.  For the full
  * list see the definition below, but useful functions include:
@@ -79,99 +93,164 @@
  */
 #define DEFINE_VECTOR_TYPE(name, type)                                  \
   struct name {                                                         \
-    type *ptr;                 /* Pointer to array of items. */         \
-    size_t size;               /* Number of valid items in the array. */ \
-    size_t alloc;              /* Number of items allocated. */         \
+    type *ptr;              /* Pointer to array of items. */            \
+    size_t len;             /* Number of valid items in the array. */   \
+    size_t cap;             /* Maximum number of items. */              \
   };                                                                    \
   typedef struct name name;                                             \
                                                                         \
   /* Reserve n elements at the end of the vector.  Note space is        \
-   * allocated but the vector size is not increased and the new         \
-   * elements are not initialized.                                      \
+   * allocated and capacity is increased, but the vector length is      \
+   * not increased and the new elements are not initialized.            \
    */                                                                   \
-  static inline int                                                     \
+  static inline int __attribute__ ((__unused__))                        \
   name##_reserve (name *v, size_t n)                                    \
   {                                                                     \
     return generic_vector_reserve ((struct generic_vector *)v, n,       \
                                    sizeof (type));                      \
   }                                                                     \
                                                                         \
-  /* Insert at i'th element.  i=0 => beginning  i=size => append */     \
-  static inline int                                                     \
+  /* Same as _reserve, but the allocation will be page aligned.  Note   \
+   * that the machine page size must be divisible by sizeof (type).     \
+   */                                                                   \
+  static inline int __attribute__ ((__unused__))                        \
+  name##_reserve_page_aligned (name *v, size_t n)                       \
+  {                                                                     \
+    return generic_vector_reserve_page_aligned ((struct generic_vector *)v, \
+                                                n, sizeof (type));      \
+  }                                                                     \
+                                                                        \
+  /* Insert at i'th element.  i=0 => beginning  i=len => append */      \
+  static inline int __attribute__ ((__unused__))                        \
   name##_insert (name *v, type elem, size_t i)                          \
   {                                                                     \
-    assert (i <= v->size);                                              \
-    if (v->size >= v->alloc) {                                          \
+    assert (i <= v->len);                                               \
+    if (v->len >= v->cap) {                                             \
       if (name##_reserve (v, 1) == -1) return -1;                       \
     }                                                                   \
-    memmove (&v->ptr[i+1], &v->ptr[i], (v->size-i) * sizeof (elem));    \
+    memmove (&v->ptr[i+1], &v->ptr[i], (v->len-i) * sizeof (elem));     \
     v->ptr[i] = elem;                                                   \
-    v->size++;                                                          \
+    v->len++;                                                           \
     return 0;                                                           \
   }                                                                     \
                                                                         \
   /* Append a new element to the end of the vector. */                  \
-  static inline int                                                     \
+  static inline int __attribute__ ((__unused__))                        \
   name##_append (name *v, type elem)                                    \
   {                                                                     \
-    return name##_insert (v, elem, v->size);                            \
+    return name##_insert (v, elem, v->len);                             \
   }                                                                     \
                                                                         \
-  /* Remove i'th element.  i=0 => beginning  i=size-1 => end */         \
-  static inline void                                                    \
+  /* Remove i'th element.  i=0 => beginning  i=len-1 => end */          \
+  static inline void __attribute__ ((__unused__))                       \
   name##_remove (name *v, size_t i)                                     \
   {                                                                     \
-    assert (i < v->size);                                               \
-    memmove (&v->ptr[i], &v->ptr[i+1], (v->size-i) * sizeof (type));    \
-    v->size--;                                                          \
+    assert (i < v->len);                                                \
+    memmove (&v->ptr[i], &v->ptr[i+1], (v->len-i-1) * sizeof (type));   \
+    v->len--;                                                           \
   }                                                                     \
                                                                         \
   /* Remove all elements and deallocate the vector. */                  \
-  static inline void                                                    \
+  static inline void __attribute__ ((__unused__))                       \
   name##_reset (name *v)                                                \
   {                                                                     \
     free (v->ptr);                                                      \
     v->ptr = NULL;                                                      \
-    v->size = v->alloc = 0;                                             \
+    v->len = v->cap = 0;                                                \
   }                                                                     \
                                                                         \
   /* Iterate over the vector, calling f() on each element. */           \
-  static inline void                                                    \
+  static inline void __attribute__ ((__unused__))                       \
   name##_iter (name *v, void (*f) (type elem))                          \
   {                                                                     \
     size_t i;                                                           \
-    for (i = 0; i < v->size; ++i)                                       \
+    for (i = 0; i < v->len; ++i)                                        \
       f (v->ptr[i]);                                                    \
   }                                                                     \
                                                                         \
   /* Sort the elements of the vector. */                                \
-  static inline void                                                    \
+  static inline void __attribute__ ((__unused__))                       \
   name##_sort (name *v,                                                 \
                int (*compare) (const type *p1, const type *p2))         \
   {                                                                     \
-    qsort (v->ptr, v->size, sizeof (type), (void *) compare);           \
+    qsort (v->ptr, v->len, sizeof (type), (void *) compare);            \
   }                                                                     \
                                                                         \
   /* Search for an exactly matching element in the vector using a       \
    * binary search.  Returns a pointer to the element or NULL.          \
    */                                                                   \
-  static inline type *                                                  \
+  static inline type * __attribute__ ((__unused__))                     \
   name##_search (const name *v, const void *key,                        \
                  int (*compare) (const void *key, const type *v))       \
   {                                                                     \
-    return bsearch (key, v->ptr, v->size, sizeof (type),                \
+    return bsearch (key, v->ptr, v->len, sizeof (type),                 \
                     (void *) compare);                                  \
-  }
+  }                                                                     \
+                                                                        \
+  /* Make a new vector with the same elements. */                       \
+  static inline int __attribute__ ((__unused__))                        \
+  name##_duplicate (name *v, name *copy)                                \
+  {                                                                     \
+    /* Note it's allowed for v and copy to be the same pointer. */      \
+    type *vptr = v->ptr;                                                \
+    type *newptr;                                                       \
+    size_t len = v->len * sizeof (type);                                \
+                                                                        \
+    newptr = malloc (len);                                              \
+    if (newptr == NULL) return -1;                                      \
+    memcpy (newptr, vptr, len);                                         \
+    copy->ptr = newptr;                                                 \
+    copy->len = copy->cap = v->len;                                     \
+    return 0;                                                           \
+  }                                                                     \
+                                                                        \
+  /* End with duplicate declaration, so callers must supply ';'. */     \
+  struct name
 
-#define empty_vector { .ptr = NULL, .size = 0, .alloc = 0 }
+#define empty_vector { .ptr = NULL, .len = 0, .cap = 0 }
+
+/* This macro should only be used if:
+ * - the vector contains pointers, and
+ * - the pointed-to objects are:
+ *   - neither const- nor volatile-qualified, and
+ *   - allocated with malloc() or equivalent.
+ */
+#define ADD_VECTOR_EMPTY_METHOD(name)                                  \
+  /* Call free() on each element of the vector, then reset the vector. \
+   */                                                                  \
+  static inline void __attribute__ ((__unused__))                      \
+  name##_empty (name *v)                                               \
+  {                                                                    \
+    size_t i;                                                          \
+    for (i = 0; i < v->len; ++i) {                                     \
+      STATIC_ASSERT (TYPE_IS_POINTER (v->ptr[i]),                      \
+                     _vector_contains_pointers);                       \
+      free (v->ptr[i]);                                                \
+    }                                                                  \
+    name##_reset (v);                                                  \
+  }                                                                    \
+                                                                       \
+  /* Force callers to supply ';'. */                                   \
+  struct name
+
+/* Convenience macro tying together DEFINE_VECTOR_TYPE() and
+ * ADD_VECTOR_EMPTY_METHOD(). Inherit and forward the requirement for a
+ * trailing semicolon from ADD_VECTOR_EMPTY_METHOD() to the caller.
+ */
+#define DEFINE_POINTER_VECTOR_TYPE(name, type) \
+  DEFINE_VECTOR_TYPE (name, type);             \
+  ADD_VECTOR_EMPTY_METHOD (name)
 
 struct generic_vector {
   void *ptr;
-  size_t size;
-  size_t alloc;
+  size_t len;
+  size_t cap;
 };
 
 extern int generic_vector_reserve (struct generic_vector *v,
                                    size_t n, size_t itemsize);
 
+extern int generic_vector_reserve_page_aligned (struct generic_vector *v,
+                                                size_t n, size_t itemsize);
+
 #endif /* NBDKIT_VECTOR_H */
