@@ -70,12 +70,13 @@ struct rule {
   struct rule *next;
   enum { BAD = 0,
          ANY, ANYV4, ANYV6, IPV4, IPV6,
-         ANYUNIX, PID, UID, GID,
+         ANYUNIX, PID, UID, GID, SECURITY,
          ANYVSOCK, VSOCKCID, VSOCKPORT } type;
   union {
     struct in_addr ipv4;        /* for IPV4, IPV6 */
     struct in6_addr ipv6;
     int64_t id;                 /* for PID, UID, GID, VSOCKCID, VSOCKPORT */
+    const char *label;          /* for SECURITY */
   } u;
   unsigned prefixlen;           /* for IPV4, IPV6 */
 };
@@ -126,6 +127,9 @@ print_rule (const char *name, const struct rule *rule, const char *suffix)
   case GID:
     nbdkit_debug ("%s=gid:%" PRIi64 "%s", name, rule->u.id, suffix);
     break;
+  case SECURITY:
+    nbdkit_debug ("%s=security:%s%s", name, rule->u.label, suffix);
+    break;
 
   case ANYVSOCK:
     nbdkit_debug ("%s=anyvsock%s", name, suffix);
@@ -303,6 +307,12 @@ parse_rule (const char *paramname,
     return 0;
   }
 
+  if (n >= 9 && ascii_strncasecmp (value, "security:", 9) == 0) {
+    new_rule->type = SECURITY;
+    new_rule->u.label = &value[9];
+    return 0;
+  }
+
   if (n == 8 && (ascii_strncasecmp (value, "allvsock", 8) == 0 ||
                  ascii_strncasecmp (value, "anyvsock", 8) == 0)) {
     new_rule->type = ANYVSOCK;
@@ -482,6 +492,8 @@ matches_rule (const struct rule *rule,
 #if defined (AF_VSOCK) && defined (VMADDR_CID_ANY)
   const struct sockaddr_vm *svm;
 #endif
+  char *label;
+  bool b;
 
   switch (rule->type) {
   case ANY:
@@ -522,6 +534,23 @@ matches_rule (const struct rule *rule,
     if (family != AF_UNIX) return false;
     return nbdkit_peer_gid () == rule->u.id;
 
+  case SECURITY:
+    b = false;
+    switch (family) {
+    case AF_UNIX:
+    case AF_INET:
+    case AF_INET6:
+      label = nbdkit_peer_security_context ();
+      if (label) {
+        if (ip_debug_rules)
+          nbdkit_debug ("ip: peer security context = \"%s\"", label);
+        b = strcmp (label, rule->u.label) == 0;
+      }
+      free (label);
+      break;
+    }
+    return b;
+
 #if defined (AF_VSOCK) && defined (VMADDR_CID_ANY)
   case ANYVSOCK:
     return family == AF_VSOCK;
@@ -582,17 +611,67 @@ check_if_allowed (const struct sockaddr *addr)
       )
     return true;
 
-  if (matches_rules_list ("ip: match source with allow",
+  if (matches_rules_list ("ip: match client with allow",
                           allow_rules, family, addr))
     return true;
 
-  if (matches_rules_list ("ip: match source with deny",
+  if (matches_rules_list ("ip: match client with deny",
                           deny_rules, family, addr))
     return false;
 
   return true;
 }
 
+/* Print the peer name in preconnect, when -D ip.rules=1 */
+static void
+print_peer_name (const struct sockaddr *sa)
+{
+  switch (sa->sa_family) {
+  case AF_UNIX:
+    /* We don't allow matching on socket paths at the moment, so just
+     * print AF_UNIX here (and in any case on Linux the peer has an
+     * empty socket path).
+     */
+    nbdkit_debug ("ip: preconnect: client is a Unix domain socket");
+    break;
+
+  case AF_INET: {
+#ifdef HAVE_INET_NTOP
+    const struct sockaddr_in *sin = (struct sockaddr_in *) sa;
+    char buf[INET_ADDRSTRLEN];
+    nbdkit_debug ("ip: preconnect: client is %s port %d",
+                  inet_ntop (sa->sa_family, &sin->sin_addr, buf, sizeof buf),
+                  ntohs (sin->sin_port));
+#endif
+    break;
+  }
+
+  case AF_INET6: {
+#ifdef HAVE_INET_NTOP
+    const struct sockaddr_in6 *sin6 = (struct sockaddr_in6 *) sa;
+    char buf[INET6_ADDRSTRLEN];
+    nbdkit_debug ("ip: preconnect: client is %s port %d",
+                  inet_ntop (sa->sa_family, &sin6->sin6_addr, buf, sizeof buf),
+                  ntohs (sin6->sin6_port));
+#endif
+    break;
+  }
+
+#if defined (AF_VSOCK) && defined (VMADDR_CID_ANY)
+  case AF_VSOCK: {
+    const struct sockaddr_vm *svm = (struct sockaddr_vm *) sa;
+    nbdkit_debug ("ip: preconnect: client is a VSOCK socket cid %u port %u",
+                  svm->svm_cid, svm->svm_port);
+    break;
+  }
+#endif
+
+  default:
+    nbdkit_debug ("ip: preconnect: unknown client address family %d",
+                  sa->sa_family);
+  }
+}
+
 static int
 ip_preconnect (nbdkit_next_preconnect *next, nbdkit_backend *nxdata,
                int readonly)
@@ -602,6 +681,8 @@ ip_preconnect (nbdkit_next_preconnect *next, nbdkit_backend *nxdata,
 
   if (nbdkit_peer_name ((struct sockaddr *) &addr, &addrlen) == -1)
     return -1;                  /* We should fail closed ... */
+  if (ip_debug_rules)
+    print_peer_name ((struct sockaddr *) &addr);
 
   /* Follow the rules. */
   if (check_if_allowed ((struct sockaddr *) &addr) == false) {
