@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2013-2021 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -70,8 +70,16 @@
 #include "isaligned.h"
 #include "fdatasync.h"
 
+static enum {
+  mode_none,
+  mode_filename,
+  mode_directory,
+  mode_fd,
+  mode_dirfd,
+} mode = mode_none;
 static char *filename = NULL;
 static char *directory = NULL;
+static int filedesc = -1;
 
 /* posix_fadvise mode: -1 = don't set it, or POSIX_FADV_*. */
 static int fadvise_mode =
@@ -154,7 +162,7 @@ static pthread_mutex_t lseek_lock = PTHREAD_MUTEX_INITIALIZER;
 /* to enable: -D file.zero=1 */
 NBDKIT_DLL_PUBLIC int file_debug_zero;
 
-static bool __attribute__((unused))
+static bool __attribute__ ((unused))
 is_enotsup (int err)
 {
   return err == ENOTSUP || err == EOPNOTSUPP;
@@ -180,18 +188,48 @@ file_config (const char *key, const char *value)
    * existence checks to the last possible moment.
    */
   if (strcmp (key, "file") == 0) {
-    free (filename);
+    if (mode != mode_none) goto wrong_mode;
+    mode = mode_filename;
+    assert (filename == NULL);
     filename = nbdkit_realpath (value);
     if (!filename)
       return -1;
   }
   else if (strcmp (key, "directory") == 0 ||
            strcmp (key, "dir") == 0) {
-    free (directory);
+    if (mode != mode_none) goto wrong_mode;
+    mode = mode_directory;
+    assert (directory == NULL);
     directory = nbdkit_realpath (value);
     if (!directory)
       return -1;
   }
+  else if (strcmp (key, "fd") == 0) {
+    if (mode != mode_none) goto wrong_mode;
+    mode = mode_fd;
+    assert (filedesc == -1);
+    if (nbdkit_parse_int ("fd", value, &filedesc) == -1)
+      return -1;
+    if (filedesc <= STDERR_FILENO) {
+      nbdkit_error ("file descriptor must be > %d because "
+                    "stdin, stdout and stderr are reserved for nbdkit",
+                    STDERR_FILENO);
+      return -1;
+    }
+  }
+  else if (strcmp (key, "dirfd") == 0) {
+    if (mode != mode_none) goto wrong_mode;
+    mode = mode_dirfd;
+    assert (filedesc == -1);
+    if (nbdkit_parse_int ("dirfd", value, &filedesc) == -1)
+      return -1;
+    if (filedesc <= STDERR_FILENO) {
+      nbdkit_error ("file descriptor must be > %d because "
+                    "stdin, stdout and stderr are reserved for nbdkit",
+                    STDERR_FILENO);
+      return -1;
+    }
+  }
   else if (strcmp (key, "fadvise") == 0) {
     /* As this is a hint, if the kernel doesn't support the feature
      * ignore the parameter.
@@ -241,8 +279,12 @@ file_config (const char *key, const char *value)
     nbdkit_error ("unknown parameter '%s'", key);
     return -1;
   }
-
   return 0;
+
+ wrong_mode:
+  nbdkit_error ("%s parameter can only appear once on the command line",
+                "file|dir|fd|dirfd");
+  return -1;
 }
 
 /* Check that the user passed exactly one parameter. */
@@ -252,22 +294,23 @@ file_config_complete (void)
   int r;
   struct stat sb;
 
-  if (!filename && !directory) {
-    nbdkit_error ("you must supply either [file=]<FILENAME> or "
-                  "dir=<DIRNAME> parameter after the plugin name "
+  switch (mode) {
+  case mode_none:
+    nbdkit_error ("you must supply [file=]<FILENAME>, "
+                  "dir=<DIRNAME> or fd=<FD> "
+                  "parameter after the plugin name "
                   "on the command line");
     return -1;
-  }
-  if (filename && directory) {
-    nbdkit_error ("file= and dir= cannot be used at the same time");
-    return -1;
-  }
 
-  /* Sanity check now, rather than waiting for first client open.
-   * See also comment in .config about use of nbdkit_realpath.
-   * Yes, this is a harmless TOCTTOU race.
-   */
-  if (filename) {
+  case mode_filename:
+    assert (filename != NULL);
+    assert (directory == NULL);
+    assert (filedesc == -1);
+
+    /* Sanity check now, rather than waiting for first client open.
+     * See also comment in .config about use of nbdkit_realpath.  Yes,
+     * this is a harmless TOCTTOU race.
+     */
     r = stat (filename, &sb);
     if (r == 0 && S_ISDIR (sb.st_mode)) {
       nbdkit_error ("use dir= to serve files within %s", filename);
@@ -277,20 +320,53 @@ file_config_complete (void)
       nbdkit_error ("file is not regular or block device: %s", filename);
       return -1;
     }
-  }
-  else if (stat (directory, &sb) == -1 || !S_ISDIR (sb.st_mode)) {
-    nbdkit_error ("expecting a directory: %s", directory);
-    return -1;
+    break;
+
+  case mode_directory:
+    assert (filename == NULL);
+    assert (directory != NULL);
+    assert (filedesc == -1);
+
+    if (stat (directory, &sb) == -1 || !S_ISDIR (sb.st_mode)) {
+      nbdkit_error ("expecting a directory: %s", directory);
+      return -1;
+    }
+    break;
+
+  case mode_fd:
+    assert (filename == NULL);
+    assert (directory == NULL);
+    assert (filedesc > STDERR_FILENO);
+
+    r = fstat (filedesc, &sb);
+    if (r == -1 || !(S_ISBLK (sb.st_mode) || S_ISREG (sb.st_mode))) {
+      nbdkit_error ("fd is not regular or block device: %d", filedesc);
+      return -1;
+    }
+    break;
+
+  case mode_dirfd:
+    assert (filename == NULL);
+    assert (directory == NULL);
+    assert (filedesc > STDERR_FILENO);
+
+    r = fstat (filedesc, &sb);
+    if (r == -1 || !(S_ISDIR (sb.st_mode))) {
+      nbdkit_error ("dirfd is not a directory: %d", filedesc);
+      return -1;
+    }
   }
 
   return 0;
 }
 
 #define file_config_help \
-  "[file=]<FILENAME>     The filename to serve.\n" \
-  "dir=<DIRNAME>         A directory containing files to serve.\n" \
-  "cache=<MODE>          Set use of caching (default, none).\n" \
-  "fadise=<LEVEL>        Set fadvise hint (normal, random, sequential).\n" \
+  "[file=]<FILENAME>       The filename to serve\n" \
+  "fd=<FILE_DESCRIPTOR>    Serve file attached to file descriptor\n" \
+  "dir=<DIRNAME>           A directory containing files to serve\n" \
+  "dirfd=<FILE_DESCRIPTOR> Serve dir attached to file descriptor\n" \
+  "cache=<MODE>            Set use of caching (default, none)\n" \
+  "fadvise=<LEVEL>         Set fadvise hint (normal, random, sequential)"
 
 /* Print some extra information about how the plugin was compiled. */
 static void
@@ -302,6 +378,9 @@ file_dump_plugin (void)
 #ifdef BLKZEROOUT
   printf ("file_blkzeroout=yes\n");
 #endif
+#ifdef SEEK_HOLE
+  printf ("file_extents=yes\n");
+#endif
 #ifdef FALLOC_FL_PUNCH_HOLE
   printf ("file_falloc_fl_punch_hole=yes\n");
 #endif
@@ -310,33 +389,17 @@ file_dump_plugin (void)
 #endif
 }
 
+/* Common code for listing exports of a directory. */
 static int
-file_list_exports (int readonly, int default_only,
-                   struct nbdkit_exports *exports)
+list_exports_of_directory (struct nbdkit_exports *exports, DIR *dir)
 {
-  /* We don't fork, so no need to worry about FD_CLOEXEC on the directory */
-  DIR *dir;
   struct dirent *entry;
-  struct stat sb;
-  int fd;
 
-  if (!directory)
-    return nbdkit_add_export (exports, "", NULL);
-
-  dir = opendir (directory);
-  if (dir == NULL) {
-    nbdkit_error ("opendir: %m");
-    return -1;
-  }
-  fd = dirfd (dir);
-  if (fd == -1) {
-    nbdkit_error ("dirfd: %m");
-    closedir (dir);
-    return -1;
-  }
   errno = 0;
   while ((entry = readdir (dir)) != NULL) {
     int r = -1;
+    struct stat sb;
+
 #if HAVE_STRUCT_DIRENT_D_TYPE
     if (entry->d_type == DT_BLK || entry->d_type == DT_REG)
       r = 1;
@@ -344,24 +407,64 @@ file_list_exports (int readonly, int default_only,
       r = 0;
 #endif
     /* TODO: when chasing symlinks, is statx any nicer than fstatat? */
-    if (r < 0 && fstatat (fd, entry->d_name, &sb, 0) == 0 &&
+    if (r == -1 && fstatat (dirfd (dir), entry->d_name, &sb, 0) == 0 &&
         (S_ISREG (sb.st_mode) || S_ISBLK (sb.st_mode)))
       r = 1;
-    if (r == 1 && nbdkit_add_export (exports, entry->d_name, NULL) == -1) {
-      closedir (dir);
+    if (r == 1 && nbdkit_add_export (exports, entry->d_name, NULL) == -1)
       return -1;
-    }
     errno = 0;
   }
+
   if (errno) {
     nbdkit_error ("readdir: %m");
-    closedir (dir);
     return -1;
   }
-  closedir (dir);
+
   return 0;
 }
 
+static int
+file_list_exports (int readonly, int default_only,
+                   struct nbdkit_exports *exports)
+{
+  /* We don't fork, so no need to worry about FD_CLOEXEC on the directory */
+  DIR *dir;
+  int dfd, r;
+
+  switch (mode) {
+  case mode_filename:
+  case mode_fd:
+    return nbdkit_add_export (exports, "", NULL);
+
+  case mode_directory:
+    dir = opendir (directory);
+    if (dir == NULL) {
+      nbdkit_error ("opendir: %m");
+      return -1;
+    }
+    r = list_exports_of_directory (exports, dir);
+    closedir (dir);
+    return r;
+
+  case mode_dirfd:
+    dfd = dup (filedesc);
+    if (dfd == -1) {
+      nbdkit_error ("dup: %m");
+      return -1;
+    }
+    dir = fdopendir (dfd);
+    if (dir == NULL) {
+      nbdkit_error ("fdopendir: %m");
+      return -1;
+    }
+    r = list_exports_of_directory (exports, dir);
+    closedir (dir); /* also closes dfd */
+    return r;
+
+  default: abort ();
+  }
+}
+
 /* The per-connection handle. */
 struct handle {
   int fd;
@@ -374,49 +477,28 @@ struct handle {
   bool can_zeroout;
 };
 
-/* Create the per-connection handle. */
-static void *
-file_open (int readonly)
+/* Common code for opening a file by name, used by mode_filename and
+ * mode_directory only.  If successful, sets h->fd and may adjust
+ * h->can_write.
+ */
+static int
+open_file_by_name (struct handle *h, int readonly, int dfd, const char *file)
 {
-  struct handle *h;
-  struct stat statbuf;
   int flags;
-  const char *file;
-  int dfd = -1;
 
-  if (directory) {
-    file = nbdkit_export_name ();
-    if (strchr (file, '/')) {
-      nbdkit_error ("exportname cannot contain /");
-      errno = EINVAL;
-      return NULL;
-    }
-    dfd = open (directory, O_RDONLY | O_DIRECTORY | O_CLOEXEC);
-    if (dfd == -1) {
-      nbdkit_error ("open %s: %m", directory);
-      return NULL;
-    }
-  }
-  else
-    file = filename;
+  assert (h->fd == -1);
 
-  h = malloc (sizeof *h);
-  if (h == NULL) {
-    nbdkit_error ("malloc: %m");
-    if (dfd != -1)
-      close (dfd);
-    return NULL;
+  if (file[0] == '\0') {
+    nbdkit_error ("open: cannot use empty file name or export name (\"\")");
+    errno = ENOENT;
+    return -1;
   }
 
   flags = O_CLOEXEC|O_NOCTTY;
-  if (readonly) {
+  if (readonly)
     flags |= O_RDONLY;
-    h->can_write = false;
-  }
-  else {
+  else
     flags |= O_RDWR;
-    h->can_write = true;
-  }
 
   h->fd = openat (dfd, file, flags);
   if (h->fd == -1 && !readonly) {
@@ -428,13 +510,126 @@ file_open (int readonly)
   }
   if (h->fd == -1) {
     nbdkit_error ("open: %s: %m", file);
-    if (dfd != -1)
-      close (dfd);
-    free (h);
+    return -1;
+  }
+
+  return 0;
+}
+
+/* Create the per-connection handle. */
+static void *
+file_open (int readonly)
+{
+  struct handle *h;
+  struct stat statbuf;
+  const char *file;
+
+  h = malloc (sizeof *h);
+  if (h == NULL) {
+    nbdkit_error ("malloc: %m");
     return NULL;
   }
-  if (dfd != -1)
+  h->can_write = !readonly;
+  h->fd = -1;
+
+  switch (mode) {
+  case mode_filename:
+    file = filename;
+    if (open_file_by_name (h, readonly, -1, file) == -1) {
+      free (h);
+      return NULL;
+    }
+    break;
+
+  case mode_directory: {
+    int dfd;
+
+    file = nbdkit_export_name ();
+    if (strchr (file, '/')) {
+      nbdkit_error ("exportname cannot contain /");
+      free (h);
+      errno = EINVAL;
+      return NULL;
+    }
+    dfd = open (directory, O_RDONLY | O_DIRECTORY | O_CLOEXEC);
+    if (dfd == -1) {
+      nbdkit_error ("open %s: %m", directory);
+      free (h);
+      return NULL;
+    }
+    if (open_file_by_name (h, readonly, dfd, file) == -1) {
+      free (h);
+      close (dfd);
+      return NULL;
+    }
     close (dfd);
+    break;
+  }
+
+  case mode_fd: {
+    int r;
+
+    /* This is needed for error messages. */
+    file = "<file descriptor>";
+
+    h->fd = dup (filedesc);
+    if (h->fd == -1) {
+      nbdkit_error ("dup fd=%d: %m", filedesc);
+      free (h);
+      return NULL;
+    }
+
+    /* If the file descriptor is readonly then we should not advertise
+     * writes as they will fail later.
+     */
+    r = fcntl (h->fd, F_GETFL);
+    if (r == -1) {
+      nbdkit_error ("fcntl: F_GETFL: %m");
+      close (h->fd);
+      free (h);
+      return NULL;
+    }
+    r &= O_ACCMODE;
+    if (r == O_RDONLY)
+      h->can_write = false;
+    else if (r == O_WRONLY)
+      nbdkit_debug ("file descriptor is write-only (ie. not readable): "
+                    "NBD protocol does not support this, but continuing "
+                    "anyway!");
+    break;
+  }
+
+  case mode_dirfd: {
+    int dfd;
+
+    file = nbdkit_export_name ();
+    if (strchr (file, '/')) {
+      nbdkit_error ("exportname cannot contain /");
+      free (h);
+      errno = EINVAL;
+      return NULL;
+    }
+    /* We don't fork, so no need to worry about FD_CLOEXEC on the directory */
+    dfd = dup (filedesc);
+    if (dfd == -1) {
+      nbdkit_error ("dup dirfd=%d: %m", filedesc);
+      free (h);
+      return NULL;
+    }
+    if (open_file_by_name (h, readonly, dfd, file) == -1) {
+      free (h);
+      close (dfd);
+      return NULL;
+    }
+    close (dfd);
+    break;
+  }
+
+  default:
+    abort ();
+  }
+
+  assert (h->fd >= 0);
 
   if (fstat (h->fd, &statbuf) == -1) {
     nbdkit_error ("fstat: %s: %m", file);
@@ -681,9 +876,9 @@ file_pwrite (void *handle, const void *buf, uint32_t count, uint64_t offset,
 
 #if defined (FALLOC_FL_PUNCH_HOLE) || defined (FALLOC_FL_ZERO_RANGE)
 static int
-do_fallocate (int fd, int mode, off_t offset, off_t len)
+do_fallocate (int fd, int mode_, off_t offset, off_t len)
 {
-  int r = fallocate (fd, mode, offset, len);
+  int r = fallocate (fd, mode_, offset, len);
   if (r == -1 && errno == ENODEV) {
     /* kernel 3.10 fails with ENODEV for block device. Kernel >= 4.9 fails
        with EOPNOTSUPP in this case. Normalize errno to simplify callers. */
@@ -697,7 +892,7 @@ do_fallocate (int fd, int mode, off_t offset, off_t len)
 static int
 file_zero (void *handle, uint32_t count, uint64_t offset, uint32_t flags)
 {
-  struct handle *h __attribute__((unused)) = handle;
+  struct handle *h __attribute__ ((unused)) = handle;
 
 #ifdef FALLOC_FL_PUNCH_HOLE
   if (h->can_punch_hole && (flags & NBDKIT_FLAG_MAY_TRIM)) {
@@ -807,7 +1002,7 @@ file_zero (void *handle, uint32_t count, uint64_t offset, uint32_t flags)
   return -1;
 
 #ifdef __clang__
-  __attribute__((unused))
+  __attribute__ ((unused))
 #endif
     out:
   if ((flags & NBDKIT_FLAG_FUA) && file_flush (handle, 0) == -1)
@@ -992,4 +1187,4 @@ static struct nbdkit_plugin plugin = {
   .errno_is_preserved = 1,
 };
 
-NBDKIT_REGISTER_PLUGIN(plugin)
+NBDKIT_REGISTER_PLUGIN (plugin)
