@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2018-2020 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -114,8 +114,9 @@ floppy_config_complete (void)
 }
 
 #define floppy_config_help \
-  "dir=<DIRECTORY>     (required) The directory to serve.\n" \
-  "label=<LABEL>                  The volume label." \
+  "dir=<DIRECTORY>     (required) The directory to serve\n" \
+  "label=<LABEL>                  The volume label\n" \
+  "size=<SIZE>                    Optional total disk size"
 
 static int
 floppy_get_ready (void)
@@ -230,4 +231,4 @@ static struct nbdkit_plugin plugin = {
   .errno_is_preserved = 1,
 };
 
-NBDKIT_REGISTER_PLUGIN(plugin)
+NBDKIT_REGISTER_PLUGIN (plugin)
