@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2013 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -179,12 +179,15 @@ plugin_guestfs_config_complete (void)
   return 0;
 }
 
-#define plugin_guestfs_config_help                              \
+#define plugin_guestfs_config_help                                  \
   "connect=<URI>       (optional) libvirt connection URI\n"         \
+  "debug=on                       enable libguestfs debugging\n"    \
   "domain=<DOMAIN>                libvirt domain name\n"            \
   "disk=<DISK>                    disk name\n"                      \
+  "export=DEVICE|FILE  (required) export device or file\n"          \
+  "format=<FORMAT>                specify the format of next disk\n" \
   "mount=inspect|MOUNT            mount filesystems\n"              \
-  "export=DEVICE|FILE  (required) export device or file"
+  "trace=on                       enable libguestfs call tracing"
 
 /* Free up the structures used to store the command line arguments.
  * Note the static strings don't need to be freed.
@@ -597,4 +600,4 @@ static struct nbdkit_plugin plugin = {
   .flush             = plugin_guestfs_flush,
 };
 
-NBDKIT_REGISTER_PLUGIN(plugin)
+NBDKIT_REGISTER_PLUGIN (plugin)
