@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2018-2020 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -128,8 +128,7 @@ make_iso (void)
 static void
 iso_unload (void)
 {
-  string_vector_iter (&dirs, (void *) free);
-  free (dirs.ptr);
+  string_vector_empty (&dirs);
 
   if (fd >= 0)
     close (fd);
@@ -182,6 +181,12 @@ iso_config_complete (void)
   "params='<PARAMS>'              Extra parameters to pass.\n" \
   "prog=<ISOPROG>                 The program used to make ISOs." \
 
+static void
+iso_dump_plugin (void)
+{
+  printf ("iso_prog=%s\n", ISOPROG);
+}
+
 static int
 iso_get_ready (void)
 {
@@ -255,6 +260,7 @@ static struct nbdkit_plugin plugin = {
   .config_complete   = iso_config_complete,
   .config_help       = iso_config_help,
   .magic_config_key  = "dir",
+  .dump_plugin       = iso_dump_plugin,
   .get_ready         = iso_get_ready,
   .open              = iso_open,
   .get_size          = iso_get_size,
@@ -264,4 +270,4 @@ static struct nbdkit_plugin plugin = {
   .errno_is_preserved = 1,
 };
 
-NBDKIT_REGISTER_PLUGIN(plugin)
+NBDKIT_REGISTER_PLUGIN (plugin)
