@@ -74,6 +74,22 @@ ocaml_nbdkit_parse_size (value strv)
   CAMLreturn (rv);
 }
 
+NBDKIT_DLL_PUBLIC value
+ocaml_nbdkit_parse_probability (value whatv, value strv)
+{
+  CAMLparam2 (whatv, strv);
+  CAMLlocal1 (dv);
+  int r;
+  double d;
+
+  r = nbdkit_parse_probability (String_val (whatv), String_val (strv), &d);
+  if (r == -1)
+    caml_invalid_argument ("nbdkit_parse_probability");
+  dv = caml_copy_double (d);
+
+  CAMLreturn (dv);
+}
+
 NBDKIT_DLL_PUBLIC value
 ocaml_nbdkit_parse_bool (value strv)
 {
@@ -106,6 +122,21 @@ ocaml_nbdkit_read_password (value strv)
   CAMLreturn (rv);
 }
 
+NBDKIT_DLL_PUBLIC value
+ocaml_nbdkit_stdio_safe (value unitv)
+{
+  CAMLparam1 (unitv);
+  CAMLlocal1 (rv);
+  int r;
+
+  r = nbdkit_stdio_safe ();
+  if (r == -1)
+    caml_invalid_argument ("nbdkit_stdio_safe");
+  rv = Val_bool (r);
+
+  CAMLreturn (rv);
+}
+
 NBDKIT_DLL_PUBLIC value
 ocaml_nbdkit_realpath (value strv)
 {
@@ -155,6 +186,21 @@ ocaml_nbdkit_export_name (value unitv)
   CAMLreturn (rv);
 }
 
+NBDKIT_DLL_PUBLIC value
+ocaml_nbdkit_is_tls (value unitv)
+{
+  CAMLparam1 (unitv);
+  CAMLlocal1 (rv);
+  int r;
+
+  r = nbdkit_is_tls ();
+  if (r == -1)
+    caml_invalid_argument ("nbdkit_is_tls");
+  rv = Val_bool (r);
+
+  CAMLreturn (rv);
+}
+
 /* NB: noalloc function. */
 NBDKIT_DLL_PUBLIC value
 ocaml_nbdkit_shutdown (value unitv)
@@ -201,6 +247,43 @@ ocaml_nbdkit_api_version (value unitv)
   return Val_int (NBDKIT_API_VERSION);
 }
 
+#ifdef HAVE_CAML_SOCKETADDR_H
+
+#include <caml/socketaddr.h>
+
+#ifndef HAVE_CAML_UNIX_ALLOC_SOCKADDR
+#define caml_unix_alloc_sockaddr alloc_sockaddr /* OCaml <= 4.14 */
+#endif
+
+NBDKIT_DLL_PUBLIC value
+ocaml_nbdkit_peer_name (value unitv)
+{
+  CAMLparam1 (unitv);
+  CAMLlocal1 (rv);
+  struct sockaddr_storage sa;
+  socklen_t len = sizeof sa;
+  int r;
+
+  r = nbdkit_peer_name ((struct sockaddr *) &sa, &len);
+  if (r == -1) caml_failwith ("nbdkit_peer_name");
+
+  rv = caml_unix_alloc_sockaddr ((void *) &sa, len, -1);
+
+  CAMLreturn (rv);
+}
+
+#else /* !HAVE_CAML_SOCKETADDR_H */
+
+NBDKIT_DLL_PUBLIC value
+ocaml_nbdkit_peer_name (value unitv)
+{
+  CAMLparam1 (unitv);
+  CAMLlocal1 (rv);
+  caml_failwith ("nbdkit_peer_name is not supported by this version of OCaml");
+}
+
+#endif /* !HAVE_CAML_SOCKETADDR_H */
+
 NBDKIT_DLL_PUBLIC value
 ocaml_nbdkit_peer_pid (value unitv)
 {
@@ -233,3 +316,15 @@ ocaml_nbdkit_peer_gid (value unitv)
   rv = caml_copy_int64 (id);
   CAMLreturn (rv);
 }
+
+NBDKIT_DLL_PUBLIC value
+ocaml_nbdkit_peer_security_context (value unitv)
+{
+  CAMLparam1 (unitv);
+  CAMLlocal1 (rv);
+  char *label = nbdkit_peer_security_context ();
+  if (label == NULL) caml_failwith ("nbdkit_peer_security_context");
+  rv = caml_copy_string (label);
+  free (label);
+  CAMLreturn (rv);
+}
