@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2018-2020 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -271,7 +271,10 @@ partitioning_config_complete (void)
 
 #define partitioning_config_help \
   "file=<FILENAME>  (required) File(s) containing partitions\n" \
-  "partition-type=mbr|gpt      Partition type"
+  "partition-type=mbr|gpt      Partition type\n" \
+  "alignment=<N>               Set the alignment (bytes)\n" \
+  "mbr-id=default|0xN          Set the MBR type byte\n" \
+  "type-guid=default|GUID      Set the GPT partition type GUID"
 
 static int
 partitioning_get_ready (void)
@@ -451,4 +454,4 @@ static struct nbdkit_plugin plugin = {
   .errno_is_preserved = 1,
 };
 
-NBDKIT_REGISTER_PLUGIN(plugin)
+NBDKIT_REGISTER_PLUGIN (plugin)
