@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2013-2020 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -55,7 +55,7 @@ set_error (VALUE self, VALUE arg)
   int err;
   VALUE v;
 
-  if (TYPE(arg) == T_CLASS) {
+  if (TYPE (arg) == T_CLASS) {
     v = rb_const_get (arg, rb_intern ("Errno"));
     err = NUM2INT (v);
   } else if (TYPE (arg) == T_OBJECT) {
@@ -199,7 +199,8 @@ plugin_rb_config (const char *key, const char *value)
     int state;
 
     if (strcmp (key, "script") != 0) {
-      nbdkit_error ("the first parameter must be script=/path/to/ruby/script.rb");
+      nbdkit_error ("the first parameter must be "
+                    "script=/path/to/ruby/script.rb");
       return -1;
     }
     script = value;
@@ -545,4 +546,4 @@ static struct nbdkit_plugin plugin = {
   .zero              = plugin_rb_zero,
 };
 
-NBDKIT_REGISTER_PLUGIN(plugin)
+NBDKIT_REGISTER_PLUGIN (plugin)
