@@ -50,6 +50,8 @@ mock!{
     pub Server {}
     #[allow(dead_code)]
     impl Server for Server {
+        fn after_fork() -> Result<()> where Self: Sized;
+        fn block_size(&self) -> Result<(u32,u32,u32)>;
         fn cache(&self, count: u32, offset: u64) -> Result<()>;
         fn can_cache(&self) -> Result<CacheFlags>;
         fn can_extents(&self) -> Result<bool>;
@@ -75,7 +77,7 @@ mock!{
         fn longname() -> Option<&'static str> where Self: Sized;
         fn magic_config_key() -> Option<&'static str> where Self: Sized;
         fn name() -> &'static str where Self: Sized;
-        fn open(readonly: bool) -> Box<dyn Server> where Self: Sized;
+        fn open(readonly: bool) -> Result<Box<dyn Server>> where Self: Sized;
         fn preconnect(readonly: bool) -> Result<()> where Self: Sized;
         fn read_at(&self, buf: &mut [u8], offset: u64) -> Result<()>;
         fn thread_model() -> Result<ThreadModel> where Self: Sized;
