@@ -46,6 +46,8 @@ static mut PLUGIN: Option<*const Plugin> = None;
 static INIT: Once = Once::new();
 
 plugin!(MockServer{
+    after_fork,
+    block_size,
     cache,
     can_cache,
     can_extents,
@@ -111,7 +113,7 @@ fn with_fixture<F: FnMut(&mut Fixture)>(mut f: F) {
     let mockp = (&mut mock) as *mut Box<MockServer>;
     let open_ctx = MockServer::open_context();
     open_ctx.expect()
-        .return_once(|_| mock);
+        .return_once(|_| Ok(mock));
 
     let pluginp = unsafe { PLUGIN.unwrap()};
     let plugin = unsafe {&*pluginp};
@@ -128,6 +130,29 @@ fn with_fixture<F: FnMut(&mut Fixture)>(mut f: F) {
     (plugin.close)(handle);
 }
 
+mod block_size {
+    use super::*;
+
+    #[test]
+    fn ok() {
+        with_fixture(|fixture| {
+            unsafe{ &mut *fixture.mockp }.expect_block_size()
+                .returning(|| Ok((512,4096,65536)));
+            let block_size = fixture.plugin.block_size.as_ref().unwrap();
+            let mut min : u32 = 0;
+            let mut pref : u32 = 0;
+            let mut max : u32 = 0;
+            assert_eq!(0, (block_size)(fixture.handle,
+                                       &mut min,
+                                       &mut pref,
+                                       &mut max));
+            assert_eq!(min, 512);
+            assert_eq!(pref, 4096);
+            assert_eq!(max, 65536);
+        });
+    }
+}
+
 /// Helper for testing methods that take a handle and return a boolean
 macro_rules! can_method {
     ( $meth:ident, $expect_meth:ident ) => {
@@ -539,6 +564,44 @@ mod get_ready {
     }
 }
 
+mod after_fork {
+    use super::*;
+
+    #[test]
+    fn einval() {
+        initialize();
+        let _m = MOCK_SERVER_MTX.lock().unwrap();
+
+        let after_fork_ctx = MockServer::after_fork_context();
+        after_fork_ctx.expect()
+            .returning(|| Err(Error::new(libc::EINVAL, "foo is required")));
+
+        let pluginp = unsafe { PLUGIN.unwrap()};
+        let plugin = unsafe {&*pluginp};
+
+        let after_fork = plugin.after_fork.as_ref().unwrap();
+        assert_eq!( -1, after_fork());
+        ERRNO.with(|e| assert_eq!(libc::EINVAL, *e.borrow()));
+        ERRMSG.with(|e| assert_eq!("foo is required", *e.borrow()));
+    }
+
+    #[test]
+    fn ok() {
+        initialize();
+        let _m = MOCK_SERVER_MTX.lock().unwrap();
+
+        let after_fork_ctx = MockServer::after_fork_context();
+        after_fork_ctx.expect()
+            .returning(|| Ok(()));
+
+        let pluginp = unsafe { PLUGIN.unwrap()};
+        let plugin = unsafe {&*pluginp};
+
+        let after_fork = plugin.after_fork.as_ref().unwrap();
+        assert_eq!( 0, after_fork());
+    }
+}
+
 can_method!(is_rotational, expect_is_rotational);
 
 unload_like!(load, load_context);
