@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2018-2022 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -52,16 +52,21 @@ typedef enum exit_code {
   ERROR = 1,           /* all script error codes are mapped to this */
   MISSING = 2,         /* method missing */
   RET_FALSE = 3,       /* script exited with code 3 meaning false */
+  SHUTDOWN_OK = 4,     /* call nbdkit_shutdown(), then return OK */
+  SHUTDOWN_ERR = 5,    /* call nbdkit_shutdown(), then return ERROR */
+  DISC_FORCE = 6,      /* call nbdkit_disconnect(true); return is irrelevant */
+  DISC_SOFT_OK = 7,    /* call nbdkit_disconnect(false), return OK */
+  DISC_SOFT_ERR = 8,   /* call nbdkit_disconnect(false), return ERROR */
   /* Adjust methods.c:sh_dump_plugin when defining new codes */
-  /* 4-7 is reserved since 1.8; handle like ERROR for now */
+  /* 9-15 are reserved since 1.34; handle like ERROR for now */
 } exit_code;
 
 extern exit_code call (const char **argv)
-  __attribute__((__nonnull__ (1)));
+  __attribute__ ((__nonnull__ (1)));
 extern exit_code call_read (string *rbuf, const char **argv)
-  __attribute__((__nonnull__ (1, 2)));
+  __attribute__ ((__nonnull__ (1, 2)));
 extern exit_code call_write (const char *wbuf, size_t wbuflen,
                              const char **argv)
-  __attribute__((__nonnull__ (1, 3)));
+  __attribute__ ((__nonnull__ (1, 3)));
 
 #endif /* NBDKIT_CALL_H */
