@@ -42,7 +42,10 @@
 #include <sys/socket.h>
 #endif
 
-#define NBDKIT_API_VERSION 2
+/* Server supports API versions between 1 and MAX_API_VERSION */
+#define MAX_API_VERSION 2
+
+#define NBDKIT_API_VERSION MAX_API_VERSION
 #define NBDKIT_INTERNAL
 #include "nbdkit-plugin.h"
 #include "nbdkit-filter.h"
@@ -142,22 +145,13 @@ extern char *unixsocket;
 extern const char *user, *group;
 extern bool verbose;
 extern bool vsock;
+
 extern enum service_mode service_mode;
 extern char *uri;
 extern bool configured;
 extern int saved_stdin;
 extern int saved_stdout;
 
-/* Linked list of backends.  Each backend struct is followed by either
- * a filter or plugin struct.  "top" points to the first one.  They
- * are linked through the backend->next field.
- *
- *         ┌──────────┐    ┌──────────┐    ┌──────────┐
- * top ───▶│ backend  │───▶│ backend  │───▶│ backend  │
- *         │ b->i = 2 │    │ b->i = 1 │    │ b->i = 0 │
- *         │ filter   │    │ filter   │    │ plugin   │
- *         └──────────┘    └──────────┘    └──────────┘
- */
 extern struct backend *top;
 #define for_each_backend(b) for (b = top; b != NULL; b = b->next)
 
@@ -226,6 +220,9 @@ enum {
 struct context {
   struct nbdkit_next_ops next;  /* Must be first member, for ABI reasons */
 
+  uint64_t magic;               /* Magic number used to validate struct. */
+#define CONTEXT_MAGIC 0xc011
+
   void *handle;         /* Plugin or filter handle. */
   struct backend *b;    /* Backend that provided handle. */
   struct context *c_next; /* Underlying context, only when b->next != NULL. */
@@ -257,6 +254,9 @@ typedef enum {
 } conn_status;
 
 struct connection {
+  uint64_t magic;               /* Magic number used to validate struct. */
+#define CONN_MAGIC 0xc05
+
   /* Listed in precedence order: do not grab earlier locks in this list
    * while holding a later lock.
    */
@@ -350,6 +350,9 @@ extern int replace_vfprintf (FILE *f, const char *fmt, va_list args)
 
 /* backend.c */
 struct backend {
+  uint64_t magic;               /* Magic number used to validate struct. */
+#define BACKEND_MAGIC 0xbac
+
   /* Next filter or plugin in the chain.  This is always NULL for
    * plugins and never NULL for filters.
    */
