@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2013-2022 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -261,7 +261,7 @@ send_newstyle_option_reply_meta_context (uint32_t option, uint32_t reply,
 /* Sub-function during negotiate_handshake_newstyle, to uniformly handle
  * a client hanging up on a message boundary.
  */
-static int ATTRIBUTE_FORMAT_PRINTF(3, 4)
+static int ATTRIBUTE_FORMAT_PRINTF (3, 4)
 conn_recv_full (void *buf, size_t len, const char *fmt, ...)
 {
   GET_CONN;
@@ -758,6 +758,14 @@ negotiate_handshake_newstyle_options (void)
         break;
       }
 
+      if (conn->structured_replies) {
+        if (send_newstyle_option_reply (option, NBD_REP_ERR_INVALID) == -1)
+          return -1;
+        debug ("newstyle negotiation: %s: structured replies already in use",
+               name_of_nbd_opt (option));
+        break;
+      }
+
       if (send_newstyle_option_reply (option, NBD_REP_ACK) == -1)
         return -1;
 
