@@ -110,75 +110,13 @@ backend_default_export (struct backend *b, int readonly)
 
 /* Unit tests. */
 
+#include "human-size-test-cases.h" /* defines 'pairs' below */
+
 static bool
 test_nbdkit_parse_size (void)
 {
   size_t i;
   bool pass = true;
-  struct pair {
-    const char *str;
-    int64_t res;
-  } pairs[] = {
-    /* Bogus strings */
-    { "", -1 },
-    { "0x0", -1 },
-    { "garbage", -1 },
-    { "0garbage", -1 },
-    { "8E", -1 },
-    { "8192P", -1 },
-
-    /* Strings leading to overflow */
-    { "9223372036854775808", -1 }, /* INT_MAX + 1 */
-    { "18446744073709551614", -1 }, /* UINT64_MAX - 1 */
-    { "18446744073709551615", -1 }, /* UINT64_MAX */
-    { "18446744073709551616", -1 }, /* UINT64_MAX + 1 */
-    { "999999999999999999999999", -1 },
-
-    /* Strings representing negative values */
-    { "-1", -1 },
-    { "-2", -1 },
-    { "-9223372036854775809", -1 }, /* INT64_MIN - 1 */
-    { "-9223372036854775808", -1 }, /* INT64_MIN */
-    { "-9223372036854775807", -1 }, /* INT64_MIN + 1 */
-    { "-18446744073709551616", -1 }, /* -UINT64_MAX - 1 */
-    { "-18446744073709551615", -1 }, /* -UINT64_MAX */
-    { "-18446744073709551614", -1 }, /* -UINT64_MAX + 1 */
-
-    /* Strings we may want to support in the future */
-    { "M", -1 },
-    { "1MB", -1 },
-    { "1MiB", -1 },
-    { "1.5M", -1 },
-
-    /* Valid strings */
-    { "-0", 0 },
-    { "0", 0 },
-    { "+0", 0 },
-    { " 08", 8 },
-    { "1", 1 },
-    { "+1", 1 },
-    { "1234567890", 1234567890 },
-    { "+1234567890", 1234567890 },
-    { "9223372036854775807", INT64_MAX },
-    { "1s", 512 },
-    { "2S", 1024 },
-    { "1b", 1 },
-    { "1B", 1 },
-    { "1k", 1024 },
-    { "1K", 1024 },
-    { "1m", 1024 * 1024 },
-    { "1M", 1024 * 1024 },
-    { "+1M", 1024 * 1024 },
-    { "1g", 1024 * 1024 * 1024 },
-    { "1G", 1024 * 1024 * 1024 },
-    { "1t", 1024LL * 1024 * 1024 * 1024 },
-    { "1T", 1024LL * 1024 * 1024 * 1024 },
-    { "1p", 1024LL * 1024 * 1024 * 1024 * 1024 },
-    { "1P", 1024LL * 1024 * 1024 * 1024 * 1024 },
-    { "8191p", 1024LL * 1024 * 1024 * 1024 * 1024 * 8191 },
-    { "1e", 1024LL * 1024 * 1024 * 1024 * 1024 * 1024 },
-    { "1E", 1024LL * 1024 * 1024 * 1024 * 1024 * 1024 },
-  };
 
   for (i = 0; i < ARRAY_SIZE (pairs); i++) {
     int64_t r;
@@ -200,6 +138,92 @@ test_nbdkit_parse_size (void)
   return pass;
 }
 
+static bool
+test_nbdkit_parse_probability (void)
+{
+  size_t i;
+  bool pass = true;
+  struct pair {
+    const char *str;
+    int result;
+    double expected;
+  } tests[] = {
+    /* Bogus strings */
+    { "", -1 },
+    { "garbage", -1 },
+    { "0garbage", -1 },
+    { "1X", -1 },
+    { "1%%", -1 },
+    { "1:", -1 },
+    { "1:1:1", -1 },
+    { "1:0", -1 }, /* format is valid but divide by zero is not allowed */
+    { "1/", -1 },
+    { "1/2/3", -1 },
+
+    /* Reject inf, NaN, negative. */
+    { "inf", -1 },
+    { "nan", -1 },
+    { "inf/nan", -1 },
+    { "nan/inf", -1 },
+    { "inf/inf", -1 },
+    { "nan/nan", -1 },
+    { "-1", -1 },
+    { "-0", -1 }, /* we reject this at the moment */
+    { "1e200/1e-200", -1 }, /* explodes larger than representable */
+    { "-1/1", -1 },
+
+    /* Numbers. */
+    { "0", 0, 0 },
+    { "1", 0, 1 },
+    { "2", 0, 2 }, /* values outside [0..1] range are allowed */
+    { "0.1", 0, 0.1 },
+    { "0.5", 0, 0.5 },
+    { "0.9", 0, 0.9 },
+    { "1.0000", 0, 1 },
+    { "1e-1", 0, 0.1 },
+    { "1e-8", 0, 1e-8 },
+
+    /* Percentages. */
+    { "0%", 0, 0 },
+    { "50%", 0, 0.5 },
+    { "100%", 0, 1 },
+    { "90.25%", 0, 0.9025 },
+
+    /* N in M */
+    { "1:1000", 0, 0.001 },
+    { "1/1000", 0, 0.001 },
+    { "2:99", 0, 2.0/99 },
+    { "2/99", 0, 2.0/99 },
+    { "0:1000000", 0, 0 },
+  };
+
+  for (i = 0; i < ARRAY_SIZE (tests); i++) {
+    int r;
+    double d;
+
+    error_flagged = false;
+    r = nbdkit_parse_probability ("test", tests[i].str, &d);
+    if (r != tests[i].result) {
+      fprintf (stderr,
+               "Wrong return value for %s, got %d, expected %d\n",
+               tests[i].str, r, tests[i].result);
+      pass = false;
+    }
+    if (r == 0 && d != tests[i].expected) {
+      fprintf (stderr,
+               "Wrong result for %s, got %g, expected %g\n",
+               tests[i].str, d, tests[i].expected);
+      pass = false;
+    }
+    if ((r == -1) != error_flagged) {
+      fprintf (stderr, "Wrong error message handling for %s\n", tests[i].str);
+      pass = false;
+    }
+  }
+
+  return pass;
+}
+
 static bool
 test_nbdkit_parse_ints (void)
 {
@@ -503,6 +527,7 @@ main (int argc, char *argv[])
 {
   bool pass = true;
   pass &= test_nbdkit_parse_size ();
+  pass &= test_nbdkit_parse_probability ();
   pass &= test_nbdkit_parse_ints ();
   pass &= test_nbdkit_read_password ();
   /* nbdkit_absolute_path and nbdkit_nanosleep not unit-tested here, but
