@@ -56,7 +56,7 @@ out=test-cc-ocaml.out
 cleanup_fn rm -f $out
 rm -f $out
 
-nbdkit -v -U - cc $script a=1 b=2 c=3 d=4 \
+nbdkit -v cc $script a=1 b=2 c=3 d=4 \
        CC="$OCAMLOPT" CFLAGS="-output-obj -runtime-variant _pic -I $abs_top_srcdir/plugins/ocaml $OCAML_PLUGIN_LIBRARIES NBDKit.cmx -cclib -L../plugins/ocaml/.libs -cclib -lnbdkitocaml" \
        --run 'nbdinfo --size $uri' > $out
 test "$(cat $out)" -eq $((512 * 2048))
