@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2013-2020 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -104,7 +104,7 @@ main (int argc, char *argv[])
   exit (77);
 #endif
 
-  sockpath = web_server ("disk", check_request);
+  sockpath = web_server ("disk", check_request, false);
   if (sockpath == NULL) {
     fprintf (stderr, "%s: could not start web server thread\n", program_name);
     exit (EXIT_FAILURE);
