@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2017 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -51,7 +51,8 @@ main (int argc, char *argv[])
   char *data;
 
   if (test_start_nbdkit ("-D", "memory.dir=1",
-                         "memory", "size=100M", NULL) == -1)
+                         "memory", "100M",
+                         "allocator=" ALLOCATOR, NULL) == -1)
     exit (EXIT_FAILURE);
 
   g = guestfs_create ();
