@@ -110,7 +110,7 @@ EOF
 chmod +x test-parallel-sh.script
 
 # With --threads=1, the write should complete first because it was issued first
-nbdkit -v -t 1 -U - --filter=delay sh test-parallel-sh.script \
+nbdkit -v -t 1 --filter=delay sh test-parallel-sh.script \
   wdelay=2 rdelay=1 --run 'timeout 60s </dev/null qemu-io -f raw \
     -c "aio_write -P 2 512 512" -c "aio_read -P 1 0 512" -c aio_flush $nbd' |
     tee test-parallel-sh.out
@@ -121,7 +121,7 @@ read 512/512 bytes at offset 0"; then
 fi
 
 # With default --threads, the faster read should complete first
-nbdkit -v -U - --filter=delay sh test-parallel-sh.script \
+nbdkit -v --filter=delay sh test-parallel-sh.script \
   wdelay=2 rdelay=1 --run 'timeout 60s </dev/null qemu-io -f raw \
     -c "aio_write -P 2 512 512" -c "aio_read -P 1 0 512" -c aio_flush $nbd' |
     tee test-parallel-sh.out
@@ -133,7 +133,7 @@ fi
 
 # With --filter=noparallel, the write should complete first because it was
 # issued first. Also test that the log filter doesn't leak an fd
-nbdkit -v -U - --filter=noparallel --filter=log --filter=delay \
+nbdkit -v --filter=noparallel --filter=log --filter=delay \
   sh test-parallel-sh.script logfile=/dev/null \
   wdelay=2 rdelay=1 --run 'timeout 60s </dev/null qemu-io -f raw \
     -c "aio_write -P 2 512 512" -c "aio_read -P 1 0 512" -c aio_flush $nbd' |
