@@ -1,7 +1,6 @@
 #!/usr/bin/env bash
 # nbdkit
-# Copyright (C) 2018 Red Hat Inc.
-# All rights reserved.
+# Copyright Red Hat
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are
@@ -31,34 +30,27 @@
 # OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 
+source ./functions.sh
 set -e
 set -x
 
-if test ! -d "$SRCDIR"; then
-    echo "$0: could not locate python-exception.py"
-    exit 1
-fi
+skip_if_valgrind "because Python code leaks memory"
 
-# Python has proven very difficult to valgrind, therefore it is disabled.
-if [ "$NBDKIT_VALGRIND" = "1" ]; then
-    echo "$0: skipping Python test under valgrind."
-    exit 77
-fi
+script=$abs_top_srcdir/tests/python-exception.py
+test -f "$script"
 
 output=test-python-exception.out
-
 rm -f $output
+cleanup_fn rm -f $output
 
-nbdkit -f -v python $SRCDIR/python-exception.py test=simple > $output 2>&1 ||:
+nbdkit -f -v python $script test=simple > $output 2>&1 ||:
 cat $output
 
 grep 'this is the test string' $output
 
-nbdkit -f -v python $SRCDIR/python-exception.py test=traceback > $output 2>&1 ||:
+nbdkit -f -v python $script test=traceback > $output 2>&1 ||:
 cat $output
 
 grep 'raise_error1' $output
 grep 'raise_error2' $output
 grep 'this is the test string' $output
-
-rm $output
