@@ -47,7 +47,7 @@ export OCAML_PLUGIN_LIBRARIES
 # For unclear reasons linking the OCaml plugin fails on macOS. XXX
 requires_not test "$(uname)" = "Darwin"
 
-$script -fv -U - \
+$script -fv \
         EXTRA_CFLAGS="-I ../plugins/ocaml -I ../plugins/ocaml/.libs" \
         size=512 \
         --run '
