@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # nbdkit
-# Copyright (C) 2018-2020 Red Hat Inc.
+# Copyright Red Hat
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are
@@ -38,13 +38,7 @@ requires test "x$vddkdir" != "x"
 requires test -d "$vddkdir"
 requires test -f "$vddkdir/lib64/libvixDiskLib.so"
 requires $CUT --version
-
-# Testing $LD_LIBRARY_PATH stuff breaks valgrind, so skip the rest of
-# this test if valgrinding.
-if [ "x$NBDKIT_VALGRIND" = "x1" ]; then
-    echo "$0: skipped LD_LIBRARY_PATH test when doing valgrind"
-    exit 77
-fi
+skip_if_valgrind "because setting LD_LIBRARY_PATH breaks valgrind"
 
 # VDDK > 5.1.1 only supports x86_64.
 if [ `uname -m` != "x86_64" ]; then
